@@ -85,12 +85,16 @@ use Collection::Utl::ActiveRecord;
 use Collection::Utl::Base;
 use Collection::Utl::LazyObject;
 @Collection::ISA     = qw(Collection::Utl::Base);
-$Collection::VERSION = '0.53';
-attributes qw( _obj_cache );
+$Collection::VERSION = '0.55';
+attributes qw( _obj_cache  _on_store _on_create _on_delete);
 
 sub _init {
     my $self = shift;
+    my %arg  = @_;
     $self->_obj_cache( {} );
+    $self->_on_store( $arg{on_store} );
+    $self->_on_create( $arg{on_create} );
+    $self->_on_delete( $arg{on_delete} );
     $self->SUPER::_init(@_);
 }
 
@@ -189,7 +193,13 @@ sub create {
     my $self     = shift;
     my $coll_ref = $self->_obj_cache();
     my $results  = $self->_create(@_);
-    return $self->fetch( keys %$results );
+    my $created = $self->fetch( keys %$results );
+    if (%$created) {
+      if ( ref( $self->_on_create ) eq 'CODE' ) {
+        $self->_on_create()->(%$created);
+      }
+    }
+    return $created
 }
 
 =head2 fetch_one(ID1), get_one(ID1)
@@ -323,12 +333,15 @@ sub store {
     foreach my $id (@store_ids) {
         my $ref = $coll_ref->{$id};
         next unless ref($ref);
-        if ( ( ref($ref) eq 'HASH' ) ? $ref->{_changed} : $ref->_changed() ) {
-            $to_store{$id} = $ref;
+        if ( $self->is_record_changed($ref) ) {
+           $to_store{$id} = $ref;
         }
     }
     if (%to_store) {
-        $self->_store( \%to_store );
+      if ( ref( $self->_on_store ) eq 'CODE' ) {
+        $self->_on_store()->(%to_store );
+      }
+      $self->_store( \%to_store );
     }
 }
 
@@ -345,6 +358,9 @@ sub delete {
     my $self = shift;
     my (@ids) =  @_;
     $self->release(@ids);
+    if ( ref( $self->_on_delete ) eq 'CODE' ) {
+        $self->_on_delete()->(@ids);
+    }
     $self->_delete(@ids);
 }
 
@@ -360,22 +376,35 @@ sub get_lazy {
     return new Collection::Utl::LazyObject:: sub { $self->fetch_one($id) };
 }
 
+sub is_record_changed {
+    my $self = shift;
+    my $record = shift || return;
+    if ( ref($record) eq 'HASH' ) {
+        return $record->{_changed};
+=pod
+        if ( my $obj = tied $value ) {
+            push @changed, $id if $obj->_changed();
+        }
+        else {
+            push @changed, $id if $value->{_changed};
+        }
+=cut
+
+    }
+    else {
+        return $record->_changed() if UNIVERSAL::can($record, '_changed');
+        return $self->is_record_changed( $record->_get_attr ) if UNIVERSAL::can($record, '_get_attr');
+        carp "Can't check is record changed for class: " . ref($record);
+    }
+
+}
+
 sub get_changed_id {
     my $self     = shift;
     my $coll_ref = $self->_obj_cache();
     my @changed  = ();
     while ( my ( $id, $value ) = each %$coll_ref ) {
-        if ( ref($value) eq 'HASH' ) {
-            if ( my $obj = tied $value ) {
-                push @changed, $id if $obj->_changed();
-            }
-            else {
-                push @changed, $id if $value->{_changed};
-            }
-        }
-        else {
-            push @changed, $id if $value->_changed();
-        }
+            push @changed, $id if $self->is_record_changed($value)
     }
     return \@changed;
 }
